==> afghknxs-2.1.2-py3-none-any.whl: adarsh/spotiboost.py <==
from adarsh.follow_bot import spotify
import threading, os, time

lock = threading.Lock()
counter = 0
proxies = []
proxy_counter = 0

print("""
________________________________________________________________
 ____  ____   ___ _____ ___ _______   __
/ ___||  _ \ / _ \_   _|_ _|  ___\ \ / /
\___ \| |_) | | | || |  | || |_   \ V / 
 ___) |  __/| |_| || |  | ||  _|   | |  
|____/|_|    \___/ |_| |___|_|     |_|  
                                        
 _____ ___  _     _     _____        _______ ____  ____  
|  ___/ _ \| |   | |   / _ \ \      / / ____|  _ \/ ___| 
| |_ | | | | |   | |  | | | \ \ /\ / /|  _| | |_) \___ \ 
|  _|| |_| | |___| |__| |_| |\ V  V / | |___|  _ < ___) |
|_|   \___/|_____|_____\___/  \_/\_/  |_____|_| \_\____/ 
                                                         
 ____   ___   ___  ____ _____ _____ ____  
| __ ) / _ \ / _ \/ ___|_   _| ____|  _ \ 
|  _ \| | | | | | \___ \ | | |  _| | |_) |
| |_) | |_| | |_| |___) || | | |___|  _ < 
|____/ \___/ \___/|____/ |_| |_____|_| \_\

_________________________________________________________________

\n\nCoded By Adarsh Goel                                          """)
spotify_profile = input("enter username on which you want to increase followers or provide link to the profile")
threads = int(input("enter desired speed (we recommend 15)"))
print("using default speed of 20X")

option = 2


def safe_print(arg):
    lock.acquire()
    print(arg)
    lock.release()

def thread_starter():
    global counter
    obj = spotify(spotify_profile)
    result, error = obj.follow()
    if result == True:
        counter += 1
        safe_print("Followed {}".format(counter))
    else:
        safe_print(f"Error {error}")

while True:
    if threading.active_count() <= threads:
        try:
            threading.Thread(target = thread_starter).start()
            proxy_counter += 1
        except:
            pass
        if len(proxies) <= proxy_counter: #Loops through proxy file
            proxy_counter = 0

==> afghknxs-2.1.5-py3-none-any.whl: adarsh/spotiboost.py <==
from adarsh.follow_bot import spotify
import threading, os, time

lock = threading.Lock()
counter = 0
proxies = []
proxy_counter = 0

print("""
________________________________________________________________
 ____  ____   ___ _____ ___ _______   __
/ ___||  _ \ / _ \_   _|_ _|  ___\ \ / /
\___ \| |_) | | | || |  | || |_   \ V / 
 ___) |  __/| |_| || |  | ||  _|   | |  
|____/|_|    \___/ |_| |___|_|     |_|  
                                        
 _____ ___  _     _     _____        _______ ____  ____  
|  ___/ _ \| |   | |   / _ \ \      / / ____|  _ \/ ___| 
| |_ | | | | |   | |  | | | \ \ /\ / /|  _| | |_) \___ \ 
|  _|| |_| | |___| |__| |_| |\ V  V / | |___|  _ < ___) |
|_|   \___/|_____|_____\___/  \_/\_/  |_____|_| \_\____/ 
                                                         
 ____   ___   ___  ____ _____ _____ ____  
| __ ) / _ \ / _ \/ ___|_   _| ____|  _ \ 
|  _ \| | | | | | \___ \ | | |  _| | |_) |
| |_) | |_| | |_| |___) || | | |___|  _ < 
|____/ \___/ \___/|____/ |_| |_____|_| \_\

_________________________________________________________________

\n\nCoded By Adarsh Goel                                          """)
spotify_profile = input("enter username on which you want to increase followers or provide link to the profile\n>> ")
threads = int(input("Enter Desired Speed (we recommend 15 \n>> )"))
print(f"Running At {threads}X Speed")

option = 2


def safe_print(arg):
    lock.acquire()
    print(arg)
    lock.release()

def thread_starter():
    global counter
    obj = spotify(spotify_profile)
    result, error = obj.follow()
    if result == True:
        counter += 1
        safe_print("Followed {}".format(counter))
    else:
        safe_print(f"Error {error}")

while True:
    if threading.active_count() <= threads:
        try:
            threading.Thread(target = thread_starter).start()
            proxy_counter += 1
        except:
            pass
        if len(proxies) <= proxy_counter: #Loops through proxy file
            proxy_counter = 0
